Exception: Bayarcash::NotFoundError

Inherits:
Error
  • Object
show all
Defined in:
lib/bayarcash/errors.rb

Overview

Raised on HTTP 404 responses.

Instance Method Summary collapse

Constructor Details

#initialize(message = "The resource you are looking for could not be found.") ⇒ NotFoundError

Returns a new instance of NotFoundError.



20
21
22
# File 'lib/bayarcash/errors.rb', line 20

def initialize(message = "The resource you are looking for could not be found.")
  super
end